summaryrefslogtreecommitdiffstats
path: root/include/sysemu/blockdev.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/sysemu/blockdev.h')
-rw-r--r--include/sysemu/blockdev.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/sysemu/blockdev.h b/include/sysemu/blockdev.h
index 134712b500..0fdbd689c1 100644
--- a/include/sysemu/blockdev.h
+++ b/include/sysemu/blockdev.h
@@ -37,7 +37,7 @@ struct DriveInfo {
int bus;
int unit;
int auto_del; /* see blockdev_mark_auto_del() */
- bool enable_auto_del; /* Only for legacy drive_init() */
+ bool enable_auto_del; /* Only for legacy drive_new() */
int media_cd;
int cyls, heads, secs, trans;
QemuOpts *opts;
@@ -57,7 +57,7 @@ DriveInfo *drive_get_by_blockdev(BlockDriverState *bs);
QemuOpts *drive_def(const char *optstr);
QemuOpts *drive_add(BlockInterfaceType type, int index, const char *file,
const char *optstr);
-DriveInfo *drive_init(QemuOpts *arg, BlockInterfaceType block_default_type);
+DriveInfo *drive_new(QemuOpts *arg, BlockInterfaceType block_default_type);
/* device-hotplug */